@@ -2,7 +2,9 @@ from peek_plugin_base.PeekPlatformCommonHookABC import PeekPlatformCommonHookABC
 from peek_plugin_base.PeekPlatformFileStorageHookABC import (
     PeekPlatformFileStorageHookABC,
 )
-from peek_plugin_base.PeekPlatformServerInfoHookABC import PeekPlatformServerInfoHookABC
+from peek_plugin_base.PeekPlatformServerInfoHookABC import (
+    PeekPlatformServerInfoHookABC,
+)
 from peek_plugin_base.client.PeekPlatformOfficeHttpHookABC import (
     PeekPlatformOfficeHttpHookABC,
 )
